==> zio-aws-timestreamquery_3-5.17.129.1-sources.jar: zio/aws/timestreamquery/model/package.scala <==
package zio.aws.timestreamquery
import zio.prelude.Subtype
import zio.aws.timestreamquery.model.primitives.TagKey
import java.time.Instant
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object AmazonResourceName extends Subtype[String]
    type AmazonResourceName =
      zio.aws.timestreamquery.model.primitives.AmazonResourceName.Type
    object ClientRequestToken extends Subtype[String]
    type ClientRequestToken =
      zio.aws.timestreamquery.model.primitives.ClientRequestToken.Type
    object ClientToken extends Subtype[String]
    type ClientToken = zio.aws.timestreamquery.model.primitives.ClientToken.Type
    object ErrorMessage extends Subtype[String]
    type ErrorMessage =
      zio.aws.timestreamquery.model.primitives.ErrorMessage.Type
    object MaxQueryResults extends Subtype[Int]
    type MaxQueryResults =
      zio.aws.timestreamquery.model.primitives.MaxQueryResults.Type
    object MaxScheduledQueriesResults extends Subtype[Int]
    type MaxScheduledQueriesResults =
      zio.aws.timestreamquery.model.primitives.MaxScheduledQueriesResults.Type
    object MaxTagsForResourceResult extends Subtype[Int]
    type MaxTagsForResourceResult =
      zio.aws.timestreamquery.model.primitives.MaxTagsForResourceResult.Type
    object NextScheduledQueriesResultsToken extends Subtype[String]
    type NextScheduledQueriesResultsToken =
      zio.aws.timestreamquery.model.primitives.NextScheduledQueriesResultsToken.Type
    object NextTagsForResourceResultsToken extends Subtype[String]
    type NextTagsForResourceResultsToken =
      zio.aws.timestreamquery.model.primitives.NextTagsForResourceResultsToken.Type
    object NullableBoolean extends Subtype[Boolean]
    type NullableBoolean =
      zio.aws.timestreamquery.model.primitives.NullableBoolean.Type
    object PaginationToken extends Subtype[String]
    type PaginationToken =
      zio.aws.timestreamquery.model.primitives.PaginationToken.Type
    object QueryId extends Subtype[String]
    type QueryId = zio.aws.timestreamquery.model.primitives.QueryId.Type
    object QueryString extends Subtype[String]
    type QueryString = zio.aws.timestreamquery.model.primitives.QueryString.Type
    object ResourceName extends Subtype[String]
    type ResourceName =
      zio.aws.timestreamquery.model.primitives.ResourceName.Type
    object S3BucketName extends Subtype[String]
    type S3BucketName =
      zio.aws.timestreamquery.model.primitives.S3BucketName.Type
    object S3ObjectKey extends Subtype[String]
    type S3ObjectKey = zio.aws.timestreamquery.model.primitives.S3ObjectKey.Type
    object S3ObjectKeyPrefix extends Subtype[String]
    type S3ObjectKeyPrefix =
      zio.aws.timestreamquery.model.primitives.S3ObjectKeyPrefix.Type
    object ScalarValue extends Subtype[String]
    type ScalarValue = zio.aws.timestreamquery.model.primitives.ScalarValue.Type
    object ScheduleExpression extends Subtype[String]
    type ScheduleExpression =
      zio.aws.timestreamquery.model.primitives.ScheduleExpression.Type
    object ScheduledQueryName extends Subtype[String]
    type ScheduledQueryName =
      zio.aws.timestreamquery.model.primitives.ScheduledQueryName.Type
    object SchemaName extends Subtype[String]
    type SchemaName = zio.aws.timestreamquery.model.primitives.SchemaName.Type
    object StringValue2048 extends Subtype[String]
    type StringValue2048 =
      zio.aws.timestreamquery.model.primitives.StringValue2048.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.timestreamquery.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.timestreamquery.model.primitives.TagValue.Type
    object Time extends Subtype[Instant]
    type Time = zio.aws.timestreamquery.model.primitives.Time.Type
    object Timestamp extends Subtype[String]
    type Timestamp = zio.aws.timestreamquery.model.primitives.Timestamp.Type
  }
  type ColumnInfoList = List[zio.aws.timestreamquery.model.ColumnInfo]
  type DatumList = List[zio.aws.timestreamquery.model.Datum]
  type DimensionMappingList =
    List[zio.aws.timestreamquery.model.DimensionMapping]
  type Endpoints = List[zio.aws.timestreamquery.model.Endpoint]
  type MixedMeasureMappingList =
    List[zio.aws.timestreamquery.model.MixedMeasureMapping]
  type MultiMeasureAttributeMappingList =
    List[zio.aws.timestreamquery.model.MultiMeasureAttributeMapping]
  type ParameterMappingList =
    List[zio.aws.timestreamquery.model.ParameterMapping]
  type RowList = List[zio.aws.timestreamquery.model.Row]
  type ScheduledQueryList = List[zio.aws.timestreamquery.model.ScheduledQuery]
  type ScheduledQueryRunSummaryList =
    List[zio.aws.timestreamquery.model.ScheduledQueryRunSummary]
  type SelectColumnList = List[zio.aws.timestreamquery.model.SelectColumn]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.timestreamquery.model.Tag]
  type TimeSeriesDataPointList =
    List[zio.aws.timestreamquery.model.TimeSeriesDataPoint]
}

==> zio-aws-timestreamquery_3-5.19.33.1-sources.jar: zio/aws/timestreamquery/model/package.scala <==
package zio.aws.timestreamquery
import zio.prelude.Subtype
import zio.aws.timestreamquery.model.primitives.TagKey
import java.time.Instant
package object model {
  import scala.jdk.CollectionConverters.*
  object primitives {
    object AmazonResourceName extends Subtype[String]
    type AmazonResourceName =
      zio.aws.timestreamquery.model.primitives.AmazonResourceName.Type
    object ClientRequestToken extends Subtype[String]
    type ClientRequestToken =
      zio.aws.timestreamquery.model.primitives.ClientRequestToken.Type
    object ClientToken extends Subtype[String]
    type ClientToken = zio.aws.timestreamquery.model.primitives.ClientToken.Type
    object ErrorMessage extends Subtype[String]
    type ErrorMessage =
      zio.aws.timestreamquery.model.primitives.ErrorMessage.Type
    object MaxQueryResults extends Subtype[Int]
    type MaxQueryResults =
      zio.aws.timestreamquery.model.primitives.MaxQueryResults.Type
    object MaxScheduledQueriesResults extends Subtype[Int]
    type MaxScheduledQueriesResults =
      zio.aws.timestreamquery.model.primitives.MaxScheduledQueriesResults.Type
    object MaxTagsForResourceResult extends Subtype[Int]
    type MaxTagsForResourceResult =
      zio.aws.timestreamquery.model.primitives.MaxTagsForResourceResult.Type
    object NextScheduledQueriesResultsToken extends Subtype[String]
    type NextScheduledQueriesResultsToken =
      zio.aws.timestreamquery.model.primitives.NextScheduledQueriesResultsToken.Type
    object NextTagsForResourceResultsToken extends Subtype[String]
    type NextTagsForResourceResultsToken =
      zio.aws.timestreamquery.model.primitives.NextTagsForResourceResultsToken.Type
    type NullableBoolean = Boolean
    object PaginationToken extends Subtype[String]
    type PaginationToken =
      zio.aws.timestreamquery.model.primitives.PaginationToken.Type
    object QueryId extends Subtype[String]
    type QueryId = zio.aws.timestreamquery.model.primitives.QueryId.Type
    object QueryString extends Subtype[String]
    type QueryString = zio.aws.timestreamquery.model.primitives.QueryString.Type
    object ResourceName extends Subtype[String]
    type ResourceName =
      zio.aws.timestreamquery.model.primitives.ResourceName.Type
    object S3BucketName extends Subtype[String]
    type S3BucketName =
      zio.aws.timestreamquery.model.primitives.S3BucketName.Type
    object S3ObjectKey extends Subtype[String]
    type S3ObjectKey = zio.aws.timestreamquery.model.primitives.S3ObjectKey.Type
    object S3ObjectKeyPrefix extends Subtype[String]
    type S3ObjectKeyPrefix =
      zio.aws.timestreamquery.model.primitives.S3ObjectKeyPrefix.Type
    object ScalarValue extends Subtype[String]
    type ScalarValue = zio.aws.timestreamquery.model.primitives.ScalarValue.Type
    object ScheduleExpression extends Subtype[String]
    type ScheduleExpression =
      zio.aws.timestreamquery.model.primitives.ScheduleExpression.Type
    object ScheduledQueryName extends Subtype[String]
    type ScheduledQueryName =
      zio.aws.timestreamquery.model.primitives.ScheduledQueryName.Type
    object SchemaName extends Subtype[String]
    type SchemaName = zio.aws.timestreamquery.model.primitives.SchemaName.Type
    object StringValue2048 extends Subtype[String]
    type StringValue2048 =
      zio.aws.timestreamquery.model.primitives.StringValue2048.Type
    object TagKey extends Subtype[String]
    type TagKey = zio.aws.timestreamquery.model.primitives.TagKey.Type
    object TagValue extends Subtype[String]
    type TagValue = zio.aws.timestreamquery.model.primitives.TagValue.Type
    object Time extends Subtype[Instant]
    type Time = zio.aws.timestreamquery.model.primitives.Time.Type
    object Timestamp extends Subtype[String]
    type Timestamp = zio.aws.timestreamquery.model.primitives.Timestamp.Type
  }
  type ColumnInfoList = List[zio.aws.timestreamquery.model.ColumnInfo]
  type DatumList = List[zio.aws.timestreamquery.model.Datum]
  type DimensionMappingList =
    List[zio.aws.timestreamquery.model.DimensionMapping]
  type Endpoints = List[zio.aws.timestreamquery.model.Endpoint]
  type MixedMeasureMappingList =
    List[zio.aws.timestreamquery.model.MixedMeasureMapping]
  type MultiMeasureAttributeMappingList =
    List[zio.aws.timestreamquery.model.MultiMeasureAttributeMapping]
  type ParameterMappingList =
    List[zio.aws.timestreamquery.model.ParameterMapping]
  type RowList = List[zio.aws.timestreamquery.model.Row]
  type ScheduledQueryList = List[zio.aws.timestreamquery.model.ScheduledQuery]
  type ScheduledQueryRunSummaryList =
    List[zio.aws.timestreamquery.model.ScheduledQueryRunSummary]
  type SelectColumnList = List[zio.aws.timestreamquery.model.SelectColumn]
  type TagKeyList = List[TagKey]
  type TagList = List[zio.aws.timestreamquery.model.Tag]
  type TimeSeriesDataPointList =
    List[zio.aws.timestreamquery.model.TimeSeriesDataPoint]
}
